@@ -7,6 +7,6 @@ class TestUploadSlack(CustomTestCase):
     def test_send(self):
         slack = Slack()
         try:
-            slack.send_message(title="Automated message because Github api sucks dicks")
+            slack.send_message(title="Automated message", channel="TEST")
         except Exception as e:
             self.fail(e)
